"use strict";

/* eslint-disable no-console */

import { createHighlighterCore } from '@shikijs/core';
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript';
import { createContext, useContext, useEffect, useMemo, useState } from 'react';
import { jsx as _jsx } from "react/jsx-runtime";
const DEBUG = true;
function _log(...args) {
  if (DEBUG) console.log('[ShikiProvider]', ...args);
}
const ShikiContext = /*#__PURE__*/createContext(null);
export function ShikiProvider({
  children,
  initialLanguages,
  initialThemes
}) {
  const [highlighter, setHighlighter] = useState(null);
  const [isReady, setIsReady] = useState(false);
  const [error, setError] = useState(null);
  useEffect(() => {
    const initHighlighter = async () => {
      try {
        const defaultTheme = initialThemes[0];

        // Create theme with both settings and tokenColors
        const processedTheme = {
          name: defaultTheme?.name,
          type: defaultTheme?.type,
          colors: defaultTheme?.colors || {},
          tokenColors: defaultTheme?.tokenColors || [],
          settings: [{
            settings: {
              foreground: defaultTheme?.colors?.['editor.foreground'],
              background: defaultTheme?.colors?.['editor.background']
            }
          }, ...(defaultTheme?.tokenColors || []).map(rule => ({
            name: rule.name || '',
            scope: Array.isArray(rule.scope) ? rule.scope : typeof rule.scope === 'string' ? rule.scope.split(',').map(s => s.trim()) : [],
            settings: {
              foreground: rule.settings.foreground,
              fontStyle: rule.settings.fontStyle,
              background: rule.settings.background
            }
          }))]
        };
        _log('Creating highlighter with theme:', {
          name: processedTheme.name,
          tokenColors: processedTheme.tokenColors?.length,
          settings: processedTheme.settings?.length,
          sampleRule: processedTheme.settings[1]
        });
        const highlighterInstance = await createHighlighterCore({
          themes: [processedTheme],
          langs: initialLanguages,
          engine: createJavaScriptRegexEngine()
        });

        // Set theme explicitly
        if (processedTheme.name) {
          highlighterInstance.setTheme(processedTheme.name);
        } else {
          throw new Error('Processed theme name is undefined');
        }

        // Test with a comment to verify theme rules
        const testCode = `
      // This is a comment
      function test() {
        const str = "hello";
        return str;
      }
    `;
        const testTokens = highlighterInstance.codeToTokens(testCode.trim(), {
          lang: 'typescript',
          theme: processedTheme.name,
          includeExplanation: true
        });
        _log('Test tokenization:', {
          tokens: testTokens.tokens[0]?.map(token => ({
            content: token.content,
            color: token.color,
            scopes: token.explanation?.[0]?.scopes.map(s => s.scopeName),
            matches: token.explanation?.[0]?.scopes.flatMap(s => s.themeMatches || []).map(m => ({
              scope: m.scope,
              color: m.settings.foreground
            }))
          })),
          theme: highlighterInstance.getTheme(processedTheme.name)
        });
        setHighlighter(highlighterInstance);
        setIsReady(true);
        setError(null);
      } catch (err) {
        console.error('Highlighter initialization failed:', err);
        setError(err instanceof Error ? err : new Error('Initialization failed'));
        setIsReady(false);
      }
    };
    initHighlighter();
  }, [initialLanguages, initialThemes]);
  const value = useMemo(() => ({
    highlighter,
    isReady,
    error
  }), [highlighter, isReady, error]);
  return /*#__PURE__*/_jsx(ShikiContext.Provider, {
    value: value,
    children: children
  });
}
export function useShiki() {
  const context = useContext(ShikiContext);
  if (!context) {
    throw new Error('useShiki must be used within a ShikiProvider');
  }
  return context;
}
//# sourceMappingURL=SyntaxContext.js.map