"use strict";

/* eslint-disable no-console */

import React, { memo, useCallback, useEffect, useState } from 'react';
import { ScrollView, StyleSheet, Text, View } from 'react-native';
import { useShiki } from './SyntaxContext';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const DEBUG = true;
function _log(...args) {
  if (DEBUG) console.log('[SyntaxHighlighter]', ...args);
}
const styles = StyleSheet.create({
  container: {
    flex: 1
  },
  line: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  }
});
export const SyntaxHighlighter = /*#__PURE__*/memo(({
  code,
  language,
  theme,
  fontSize = 14
}) => {
  const {
    highlighter,
    isReady
  } = useShiki();
  const [tokens, setTokens] = useState([]);
  const [error, setError] = useState(null);
  const highlight = useCallback(async () => {
    if (!highlighter || !isReady) {
      _log('Highlighter not ready:', {
        highlighter: !!highlighter,
        isReady
      });
      return;
    }
    try {
      const loadedLangs = highlighter.getLoadedLanguages();
      _log('Available languages:', loadedLangs);
      const normalizedLang = language?.toLowerCase() || 'text';
      _log('Requested language:', normalizedLang);
      const langToUse = loadedLangs.includes(normalizedLang) ? normalizedLang : 'text';
      _log('Using language:', langToUse);

      // Get theme name
      const themeName = typeof theme === 'string' ? theme : theme?.name || 'github-dark';

      // Validate theme is loaded
      const loadedThemes = highlighter.getLoadedThemes();
      if (!loadedThemes.includes(themeName)) {
        throw new Error(`Theme ${themeName} not loaded. Available themes: ${loadedThemes.join(', ')}`);
      }

      // Get complete theme details
      const currentTheme = highlighter.getTheme(themeName);
      _log('Theme details:', {
        name: currentTheme.name,
        type: currentTheme.type,
        tokenColors: currentTheme.tokenColors?.length,
        settings: currentTheme.settings?.length,
        firstTokenColor: currentTheme.tokenColors?.[0]
      });

      // Use codeToTokens with explanation to debug token mapping
      const results = highlighter.codeToTokens(code.trim(), {
        lang: langToUse,
        theme: themeName,
        includeExplanation: true
      });

      // In SyntaxHighlighter.tsx
      _log('Tokenization results:', {
        lineCount: results.tokens.length,
        totalTokens: results.tokens.flat().length,
        firstLine: results.tokens[0]?.map(t => ({
          content: t.content,
          color: t.color,
          fontStyle: t.fontStyle,
          scopes: t.explanation?.[0]?.scopes.map(s => ({
            scope: s.scopeName,
            matches: s.themeMatches?.map(m => ({
              scope: m.scope,
              settings: m.settings
            }))
          }))
        })),
        uniqueColors: [...new Set(results.tokens.flat().map(t => t.color))]
      });
      setTokens(results.tokens);
      setError(null);
    } catch (err) {
      console.error('Highlighting error:', err);
      _log('Highlighting failed:', {
        error: err instanceof Error ? err.message : 'Unknown error',
        code: `${code.substring(0, 100)}...`
      });
      setError(err instanceof Error ? err.message : 'Failed to highlight code');
    }
  }, [code, language, theme, highlighter, isReady]);
  useEffect(() => {
    highlight();
  }, [highlight]);
  useEffect(() => {
    if (tokens.length > 0) {
      _log('Token analysis:', {
        lineCount: tokens.length,
        sample: tokens[0]?.slice(0, 2),
        colors: [...new Set(tokens.flat().map(t => t.color))]
      });
    }
  }, [tokens]);
  if (!isReady) {
    return /*#__PURE__*/_jsx(View, {
      style: styles.container,
      children: /*#__PURE__*/_jsx(Text, {
        style: {
          fontSize
        },
        children: code
      })
    });
  }
  if (error) {
    return /*#__PURE__*/_jsxs(View, {
      style: styles.container,
      children: [/*#__PURE__*/_jsx(Text, {
        style: {
          color: 'red'
        },
        children: error
      }), /*#__PURE__*/_jsx(Text, {
        style: {
          fontSize
        },
        children: code
      })]
    });
  }
  return /*#__PURE__*/_jsx(ScrollView, {
    horizontal: true,
    style: styles.container,
    children: /*#__PURE__*/_jsx(View, {
      children: tokens.map((line, i) => /*#__PURE__*/_jsx(View, {
        style: styles.line,
        children: line.map((token, j) => /*#__PURE__*/_jsx(Text, {
          style: {
            color: token.color,
            fontSize,
            ...(token.fontStyle && token.fontStyle & 1 && {
              fontStyle: 'italic'
            }),
            ...(token.fontStyle && token.fontStyle & 2 && {
              fontWeight: 'bold'
            }),
            ...(token.bgColor && {
              backgroundColor: token.bgColor
            })
          },
          children: token.content
        }, `${i}-${j}`))
      }, i))
    })
  });
});
//# sourceMappingURL=SyntaxHighlighter.js.map